@@ -13,7 +13,6 @@ pub enum Writable {}
 pub struct AudioBuffer<T> {
     // Has to be boxed because it contains self-references
     audio_buffer: Box<ffi::GstAudioBuffer>,
-    buffer: gst::Buffer,
     phantom: PhantomData<T>,
 }
 
@@ -43,7 +42,8 @@ impl<T> AudioBuffer<T> {
     pub fn into_buffer(self) -> gst::Buffer {
         unsafe {
             let mut s = mem::ManuallyDrop::new(self);
-            let buffer = ptr::read(&s.buffer);
+            // Take ownership of the buffer stored here when mapping before unmapping
+            let buffer = from_glib_none(s.audio_buffer.buffer);
             ffi::gst_audio_buffer_unmap(&mut *s.audio_buffer);
             ptr::drop_in_place(&mut s.audio_buffer);
 
@@ -151,7 +151,6 @@ impl<T> AudioBuffer<T> {
     pub fn as_audio_buffer_ref(&self) -> AudioBufferRef<&gst::BufferRef> {
         AudioBufferRef {
             audio_buffer: AudioBufferPtr::Borrowed(ptr::NonNull::from(&*self.audio_buffer)),
-            unmap: false,
             phantom: PhantomData,
         }
     }
@@ -166,7 +165,11 @@ impl<T> Drop for AudioBuffer<T> {
     #[inline]
     fn drop(&mut self) {
         unsafe {
+            // Take ownership again of the buffer that was stored here when mapping
+            // and then drop it after unmapping.
+            let buffer = gst::Buffer::from_glib_full(self.audio_buffer.buffer);
             ffi::gst_audio_buffer_unmap(&mut *self.audio_buffer);
+            drop(buffer);
         }
     }
 }
@@ -182,6 +185,9 @@ impl AudioBuffer<Readable> {
         assert!(info.is_valid());
 
         unsafe {
+            // Store the buffer as part of the audio buffer, we will retrieve / unref it
+            // again at a later time.
+            let buffer = mem::ManuallyDrop::new(buffer);
             let mut audio_buffer = Box::new(mem::MaybeUninit::zeroed().assume_init());
             let res: bool = from_glib(ffi::gst_audio_buffer_map(
                 &mut *audio_buffer,
@@ -191,11 +197,10 @@ impl AudioBuffer<Readable> {
             ));
 
             if !res {
-                Err(buffer)
+                Err(mem::ManuallyDrop::into_inner(buffer))
             } else {
                 Ok(Self {
                     audio_buffer,
-                    buffer,
                     phantom: PhantomData,
                 })
             }
@@ -219,6 +224,9 @@ impl AudioBuffer<Writable> {
         assert!(info.is_valid());
 
         unsafe {
+            // Store the buffer as part of the audio buffer, we will retrieve / unref it
+            // again at a later time.
+            let buffer = mem::ManuallyDrop::new(buffer);
             let mut audio_buffer = Box::new(mem::MaybeUninit::zeroed().assume_init());
             let res: bool = from_glib(ffi::gst_audio_buffer_map(
                 &mut *audio_buffer,
@@ -228,11 +236,10 @@ impl AudioBuffer<Writable> {
             ));
 
             if !res {
-                Err(buffer)
+                Err(mem::ManuallyDrop::into_inner(buffer))
             } else {
                 Ok(Self {
                     audio_buffer,
-                    buffer,
                     phantom: PhantomData,
                 })
             }
@@ -271,7 +278,6 @@ impl AudioBuffer<Writable> {
     pub fn as_mut_audio_buffer_ref(&mut self) -> AudioBufferRef<&mut gst::BufferRef> {
         AudioBufferRef {
             audio_buffer: AudioBufferPtr::Borrowed(ptr::NonNull::from(&mut *self.audio_buffer)),
-            unmap: false,
             phantom: PhantomData,
         }
     }
@@ -284,6 +290,7 @@ impl AudioBuffer<Writable> {
 
 #[derive(Debug)]
 enum AudioBufferPtr {
+    // Has to be boxed because it contains self-references
     Owned(Box<ffi::GstAudioBuffer>),
     Borrowed(ptr::NonNull<ffi::GstAudioBuffer>),
 }
@@ -311,9 +318,7 @@ impl ops::DerefMut for AudioBufferPtr {
 }
 
 pub struct AudioBufferRef<T> {
-    // Has to be boxed because it contains self-references
     audio_buffer: AudioBufferPtr,
-    unmap: bool,
     phantom: PhantomData<T>,
 }
 
@@ -448,7 +453,6 @@ impl<'a> AudioBufferRef<&'a gst::BufferRef> {
             audio_buffer: AudioBufferPtr::Borrowed(ptr::NonNull::new_unchecked(
                 audio_buffer as *mut _,
             )),
-            unmap: false,
             phantom: PhantomData,
         })
     }
@@ -476,7 +480,6 @@ impl<'a> AudioBufferRef<&'a gst::BufferRef> {
             } else {
                 Ok(Self {
                     audio_buffer: AudioBufferPtr::Owned(audio_buffer),
-                    unmap: true,
                     phantom: PhantomData,
                 })
             }
@@ -496,7 +499,6 @@ impl<'a> AudioBufferRef<&'a mut gst::BufferRef> {
 
         Borrowed::new(Self {
             audio_buffer: AudioBufferPtr::Borrowed(ptr::NonNull::new_unchecked(audio_buffer)),
-            unmap: false,
             phantom: PhantomData,
         })
     }
@@ -524,7 +526,6 @@ impl<'a> AudioBufferRef<&'a mut gst::BufferRef> {
             } else {
                 Ok(Self {
                     audio_buffer: AudioBufferPtr::Owned(audio_buffer),
-                    unmap: true,
                     phantom: PhantomData,
                 })
             }
@@ -586,7 +587,7 @@ impl<T> Drop for AudioBufferRef<T> {
     #[inline]
     fn drop(&mut self) {
         unsafe {
-            if self.unmap {
+            if matches!(self.audio_buffer, AudioBufferPtr::Owned(..)) {
                 ffi::gst_audio_buffer_unmap(&mut *self.audio_buffer);
             }
         }
