@@ -1,19 +1,18 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 use std::fmt;
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 use std::ptr;
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 use std::slice;
 
-use glib::translate::{from_glib, IntoGlib};
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
-use glib::translate::{from_glib_none, ToGlibPtr};
+use glib::translate::*;
 use gst::prelude::*;
 
+use crate::ffi;
+
 #[repr(transparent)]
 #[doc(alias = "GstAudioClippingMeta")]
 pub struct AudioClippingMeta(ffi::GstAudioClippingMeta);
@@ -27,7 +26,7 @@ impl AudioClippingMeta {
         buffer: &mut gst::BufferRef,
         start: V,
         end: V,
-    ) -> gst::MetaRefMut<Self, gst::meta::Standalone> {
+    ) -> gst::MetaRefMut<'_, Self, gst::meta::Standalone> {
         skip_assert_initialized!();
         assert_eq!(start.format(), end.format());
         unsafe {
@@ -74,21 +73,21 @@ impl fmt::Debug for AudioClippingMeta {
     }
 }
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 #[repr(transparent)]
 #[doc(alias = "GstAudioMeta")]
 pub struct AudioMeta(ffi::GstAudioMeta);
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 unsafe impl Send for AudioMeta {}
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 unsafe impl Sync for AudioMeta {}
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 impl AudioMeta {
     #[doc(alias = "gst_buffer_add_audio_meta")]
     pub fn add<'a>(
@@ -179,8 +178,8 @@ impl AudioMeta {
 
     #[doc(alias = "get_info")]
     #[inline]
-    pub fn info(&self) -> crate::AudioInfo {
-        unsafe { from_glib_none(&self.0.info as *const _ as *mut ffi::GstAudioInfo) }
+    pub fn info(&self) -> &crate::AudioInfo {
+        unsafe { &*(&self.0.info as *const ffi::GstAudioInfo as *const crate::AudioInfo) }
     }
 
     #[doc(alias = "get_samples")]
@@ -200,8 +199,8 @@ impl AudioMeta {
     }
 }
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 unsafe impl MetaAPI for AudioMeta {
     type GstType = ffi::GstAudioMeta;
 
@@ -212,8 +211,8 @@ unsafe impl MetaAPI for AudioMeta {
     }
 }
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 impl fmt::Debug for AudioMeta {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("AudioMeta")
@@ -224,28 +223,28 @@ impl fmt::Debug for AudioMeta {
     }
 }
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 #[repr(transparent)]
 #[doc(alias = "GstAudioLevelMeta")]
 pub struct AudioLevelMeta(ffi::GstAudioLevelMeta);
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 unsafe impl Send for AudioLevelMeta {}
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 unsafe impl Sync for AudioLevelMeta {}
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 impl AudioLevelMeta {
     #[doc(alias = "gst_buffer_add_audio_level_meta")]
     pub fn add(
         buffer: &mut gst::BufferRef,
         level: u8,
         voice_activity: bool,
-    ) -> gst::MetaRefMut<Self, gst::meta::Standalone> {
+    ) -> gst::MetaRefMut<'_, Self, gst::meta::Standalone> {
         skip_assert_initialized!();
         unsafe {
             let meta = ffi::gst_buffer_add_audio_level_meta(
@@ -271,8 +270,8 @@ impl AudioLevelMeta {
     }
 }
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 unsafe impl MetaAPI for AudioLevelMeta {
     type GstType = ffi::GstAudioLevelMeta;
 
@@ -283,8 +282,8 @@ unsafe impl MetaAPI for AudioLevelMeta {
     }
 }
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 impl fmt::Debug for AudioLevelMeta {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("AudioLevelMeta")
@@ -294,6 +293,17 @@ impl fmt::Debug for AudioLevelMeta {
     }
 }
 
+pub mod tags {
+    gst::impl_meta_tag!(Audio, crate::ffi::GST_META_TAG_AUDIO_STR);
+    gst::impl_meta_tag!(Channels, crate::ffi::GST_META_TAG_AUDIO_CHANNELS_STR);
+    gst::impl_meta_tag!(Rate, crate::ffi::GST_META_TAG_AUDIO_RATE_STR);
+    #[cfg(feature = "v1_24")]
+    gst::impl_meta_tag!(
+        DSDPlaneOffsets,
+        crate::ffi::GST_META_TAG_DSD_PLANE_OFFSETS_STR
+    );
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -319,6 +329,8 @@ mod tests {
             let cmeta = buffer.meta::<AudioClippingMeta>().unwrap();
             assert_eq!(cmeta.start().try_into(), Ok(Some(start)));
             assert_eq!(cmeta.end().try_into(), Ok(Some(stop)));
+
+            assert!(cmeta.has_tag::<tags::Audio>());
         }
     }
 
