@@ -1,7 +1,6 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use std::i32;
-
+use crate::ffi;
 use glib::translate::{from_glib_full, IntoGlibPtr, ToGlibPtr};
 
 #[doc(alias = "gst_audio_buffer_clip")]
@@ -23,8 +22,8 @@ pub fn audio_buffer_clip(
     }
 }
 
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 #[doc(alias = "gst_audio_buffer_truncate")]
 pub fn audio_buffer_truncate(
     buffer: gst::Buffer,
@@ -39,7 +38,7 @@ pub fn audio_buffer_truncate(
             buffer.into_glib_ptr(),
             bpf as i32,
             trim,
-            samples.unwrap_or(std::usize::MAX),
+            samples.unwrap_or(usize::MAX),
         ))
     }
 }
