@@ -1,24 +1,19 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-#![cfg_attr(feature = "dox", feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![allow(clippy::missing_safety_doc)]
-#![allow(clippy::non_send_fields_in_send_ty)]
+#![allow(clippy::manual_c_str_literals)]
 #![doc = include_str!("../README.md")]
 
-pub use ffi;
 pub use glib;
 pub use gst;
 pub use gst_base;
+pub use gstreamer_audio_sys as ffi;
 
 macro_rules! assert_initialized_main_thread {
     () => {
         if !gst::INITIALIZED.load(std::sync::atomic::Ordering::SeqCst) {
-            #[allow(unused_unsafe)]
-            if unsafe { gst::ffi::gst_is_initialized() } != glib::ffi::GTRUE {
-                panic!("GStreamer has not been initialized. Call `gst::init` first.");
-            } else {
-                gst::INITIALIZED.store(true, std::sync::atomic::Ordering::SeqCst);
-            }
+            gst::assert_initialized();
         }
     };
 }
@@ -27,10 +22,6 @@ macro_rules! skip_assert_initialized {
     () => {};
 }
 
-#[allow(clippy::unreadable_literal)]
-#[allow(clippy::too_many_arguments)]
-#[allow(clippy::match_same_arms)]
-#[allow(clippy::use_self)]
 #[allow(clippy::needless_borrow)]
 #[allow(unused_imports)]
 mod auto;
@@ -60,35 +51,33 @@ mod audio_aggregator_pad;
 mod audio_stream_align;
 mod functions;
 pub use crate::functions::*;
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 pub mod audio_buffer;
-#[cfg(any(feature = "v1_16", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+#[cfg(feature = "v1_16")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
 pub use audio_buffer::{AudioBuffer, AudioBufferRef};
 
 mod audio_decoder;
 mod audio_encoder;
+mod audio_filter;
 
 mod audio_converter;
 pub use crate::audio_converter::AudioConverterConfig;
 
-mod utils;
-
 // Re-export all the traits in a prelude module, so that applications
 // can always "use gst_audio::prelude::*" without getting conflicts
 pub mod prelude {
     #[doc(hidden)]
     pub use gst_base::prelude::*;
 
-    pub use super::audio_decoder::AudioDecoderExtManual;
-    pub use super::audio_encoder::AudioEncoderExtManual;
-    pub use crate::audio_aggregator::AudioAggregatorExtManual;
-    pub use crate::audio_aggregator_convert_pad::AudioAggregatorConvertPadExtManual;
-    pub use crate::audio_aggregator_pad::AudioAggregatorPadExtManual;
-    pub use crate::audio_format::AudioFormatIteratorExt;
-
-    pub use crate::auto::traits::*;
+    pub use super::{audio_decoder::AudioDecoderExtManual, audio_encoder::AudioEncoderExtManual};
+    pub use crate::{
+        audio_aggregator::AudioAggregatorExtManual,
+        audio_aggregator_convert_pad::AudioAggregatorConvertPadExtManual,
+        audio_aggregator_pad::AudioAggregatorPadExtManual, audio_filter::AudioFilterExtManual,
+        audio_format::AudioFormatIteratorExt, auto::traits::*,
+    };
 }
 
 pub mod subclass;
