@@ -5,9 +5,9 @@ use std::ptr;
 use glib::translate::*;
 use gst_base::{prelude::*, subclass::prelude::*};
 
-use crate::{AudioAggregator, AudioAggregatorPad};
+use crate::{ffi, AudioAggregator, AudioAggregatorPad};
 
-pub trait AudioAggregatorImpl: AudioAggregatorImplExt + AggregatorImpl {
+pub trait AudioAggregatorImpl: AggregatorImpl + ObjectSubclass<Type: IsA<AudioAggregator>> {
     fn create_output_buffer(&self, num_frames: u32) -> Option<gst::Buffer> {
         self.parent_create_output_buffer(num_frames)
     }
@@ -26,22 +26,7 @@ pub trait AudioAggregatorImpl: AudioAggregatorImplExt + AggregatorImpl {
     }
 }
 
-pub trait AudioAggregatorImplExt: ObjectSubclass {
-    fn parent_create_output_buffer(&self, num_frames: u32) -> Option<gst::Buffer>;
-
-    #[allow(clippy::too_many_arguments)]
-    fn parent_aggregate_one_buffer(
-        &self,
-        pad: &AudioAggregatorPad,
-        inbuf: &gst::BufferRef,
-        in_offset: u32,
-        outbuf: &mut gst::BufferRef,
-        out_offset: u32,
-        num_frames: u32,
-    ) -> bool;
-}
-
-impl<T: AudioAggregatorImpl> AudioAggregatorImplExt for T {
+pub trait AudioAggregatorImplExt: AudioAggregatorImpl {
     fn parent_create_output_buffer(&self, num_frames: u32) -> Option<gst::Buffer> {
         unsafe {
             let data = Self::type_data();
@@ -92,6 +77,8 @@ impl<T: AudioAggregatorImpl> AudioAggregatorImplExt for T {
     }
 }
 
+impl<T: AudioAggregatorImpl> AudioAggregatorImplExt for T {}
+
 unsafe impl<T: AudioAggregatorImpl> IsSubclassable<T> for AudioAggregator {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
