@@ -5,9 +5,11 @@ use std::ptr;
 use glib::translate::*;
 use gst_base::{prelude::*, subclass::prelude::*};
 
-use crate::AudioAggregatorPad;
+use crate::{ffi, AudioAggregatorPad};
 
-pub trait AudioAggregatorPadImpl: AudioAggregatorPadImplExt + AggregatorPadImpl {
+pub trait AudioAggregatorPadImpl:
+    AggregatorPadImpl + ObjectSubclass<Type: IsA<AudioAggregatorPad>>
+{
     const HANDLE_CONVERSION: bool = false;
 
     fn update_conversion_info(&self) {
@@ -24,18 +26,7 @@ pub trait AudioAggregatorPadImpl: AudioAggregatorPadImplExt + AggregatorPadImpl
     }
 }
 
-pub trait AudioAggregatorPadImplExt: ObjectSubclass {
-    fn parent_update_conversion_info(&self);
-
-    fn parent_convert_buffer(
-        &self,
-        in_info: &crate::AudioInfo,
-        out_info: &crate::AudioInfo,
-        buffer: &gst::Buffer,
-    ) -> Option<gst::Buffer>;
-}
-
-impl<T: AudioAggregatorPadImpl> AudioAggregatorPadImplExt for T {
+pub trait AudioAggregatorPadImplExt: AudioAggregatorPadImpl {
     fn parent_update_conversion_info(&self) {
         unsafe {
             let data = Self::type_data();
@@ -75,6 +66,8 @@ impl<T: AudioAggregatorPadImpl> AudioAggregatorPadImplExt for T {
     }
 }
 
+impl<T: AudioAggregatorPadImpl> AudioAggregatorPadImplExt for T {}
+
 unsafe impl<T: AudioAggregatorPadImpl> IsSubclassable<T> for AudioAggregatorPad {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
