@@ -5,9 +5,9 @@ use gst::LoggableError;
 use gst_base::subclass::prelude::*;
 
 use super::prelude::*;
-use crate::{AudioRingBufferSpec, AudioSink};
+use crate::{ffi, AudioRingBufferSpec, AudioSink};
 
-pub trait AudioSinkImpl: AudioSinkImplExt + AudioBaseSinkImpl {
+pub trait AudioSinkImpl: AudioBaseSinkImpl + ObjectSubclass<Type: IsA<AudioSink>> {
     fn close(&self) -> Result<(), LoggableError> {
         self.parent_close()
     }
@@ -37,17 +37,7 @@ pub trait AudioSinkImpl: AudioSinkImplExt + AudioBaseSinkImpl {
     }
 }
 
-pub trait AudioSinkImplExt: ObjectSubclass {
-    fn parent_close(&self) -> Result<(), LoggableError>;
-    fn parent_delay(&self) -> u32;
-    fn parent_open(&self) -> Result<(), LoggableError>;
-    fn parent_prepare(&self, spec: &mut AudioRingBufferSpec) -> Result<(), LoggableError>;
-    fn parent_unprepare(&self) -> Result<(), LoggableError>;
-    fn parent_write(&self, audio_data: &[u8]) -> Result<i32, LoggableError>;
-    fn parent_reset(&self);
-}
-
-impl<T: AudioSinkImpl> AudioSinkImplExt for T {
+pub trait AudioSinkImplExt: AudioSinkImpl {
     fn parent_close(&self) -> Result<(), LoggableError> {
         unsafe {
             let data = Self::type_data();
@@ -140,7 +130,7 @@ impl<T: AudioSinkImpl> AudioSinkImplExt for T {
                 Some(f) => f,
                 None => return Ok(-1),
             };
-            let buffer_ptr = buffer.as_ptr() as *const _ as *mut _;
+            let buffer_ptr = buffer.as_ptr() as glib::ffi::gpointer;
             let ret = f(
                 self.obj().unsafe_cast_ref::<AudioSink>().to_glib_none().0,
                 buffer_ptr,
@@ -168,6 +158,8 @@ impl<T: AudioSinkImpl> AudioSinkImplExt for T {
     }
 }
 
+impl<T: AudioSinkImpl> AudioSinkImplExt for T {}
+
 unsafe impl<T: AudioSinkImpl> IsSubclassable<T> for AudioSink {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
